summaryrefslogtreecommitdiffstats
path: root/tests/test-runner
diff options
context:
space:
mode:
authorBrian Behlendorf <[email protected]>2020-03-04 15:09:40 -0800
committerGitHub <[email protected]>2020-03-04 15:09:40 -0800
commit4b06d052986675c0bdcbb7eec343da24c15558b3 (patch)
treeead91b67ca94c1aeb596a5b8d683ba82dadbfd93 /tests/test-runner
parentf49db9b50427565a263e219497f18165299dee87 (diff)
ZTS: Add zts-report exceptions for FreeBSD
There are three tests we expect to fail only on FreeBSD. * link_count never exits and eventually times out: - @amotin tells me this test is probably not applicable to us - Skip on FreeBSD * userobj feature does not activate immediately after pool upgrade - low impact; we are aware of this issue * removal does not appear to condense on export - low impact; we are aware of this issue Additionally removal_with_zdb passes on FreeBSD, so it is moved to "maybe". Reviewed-by: Brian Behlendorf <[email protected]> Reviewed-by: John Kennedy <[email protected]> Signed-off-by: Ryan Moeller <[email protected]> Closes #10093
Diffstat (limited to 'tests/test-runner')
-rwxr-xr-xtests/test-runner/bin/zts-report.py17
1 files changed, 12 insertions, 5 deletions
diff --git a/tests/test-runner/bin/zts-report.py b/tests/test-runner/bin/zts-report.py
index a825c2daa..8a30ce106 100755
--- a/tests/test-runner/bin/zts-report.py
+++ b/tests/test-runner/bin/zts-report.py
@@ -121,11 +121,11 @@ fio_reason = 'Fio v2.3 or newer required'
trim_reason = 'DISKS must support discard (TRIM/UNMAP)'
#
# Some tests are not applicable to Linux or need to be updated to operate
# in the manor required by Linux. Any tests which are skipped for this
# reason will be suppressed in the final analysis output.
#
-na_reason = "N/A on Linux"
+na_reason = "Not applicable"
summary = {
'total': float(0),
@@ -153,12 +153,18 @@ known = {
'cli_user/misc/zfs_unshare_001_neg': ['SKIP', na_reason],
'privilege/setup': ['SKIP', na_reason],
'refreserv/refreserv_004_pos': ['FAIL', known_reason],
- 'removal/removal_with_zdb': ['SKIP', known_reason],
'rootpool/setup': ['SKIP', na_reason],
'rsend/rsend_008_pos': ['SKIP', '6066'],
'vdev_zaps/vdev_zaps_007_pos': ['FAIL', known_reason],
}
+if sys.platform.startswith('freebsd'):
+ known.update({
+ 'link_count/link_count_001': ['SKIP', na_reason],
+ 'removal/removal_condense_export': ['FAIL', known_reason],
+ 'upgrade/upgrade_userobj_001_pos': ['FAIL', known_reason],
+ })
+
#
# These tests may occasionally fail or be skipped. We want there failures
# to be reported but only unexpected failures should bubble up to cause
@@ -207,6 +213,7 @@ maybe = {
'no_space/enospc_002_pos': ['FAIL', enospc_reason],
'projectquota/setup': ['SKIP', exec_reason],
'redundancy/redundancy_004_neg': ['FAIL', '7290'],
+ 'removal/removal_with_zdb': ['SKIP', known_reason],
'reservation/reservation_008_pos': ['FAIL', '7741'],
'reservation/reservation_018_pos': ['FAIL', '5642'],
'rsend/rsend_019_pos': ['FAIL', '6086'],
@@ -300,7 +307,7 @@ if __name__ == "__main__":
issue_url = 'https://github.com/openzfs/zfs/issues/'
# Include the reason why the result is expected, given the following:
# 1. Suppress test results which set the "N/A on Linux" reason.
# 2. Numerical reasons are assumed to be GitHub issue numbers.
# 3. When an entire test group is skipped only report the setup reason.
if test in known:
@@ -121,11 +121,11 @@ fio_reason = 'Fio v2.3 or newer required'
trim_reason = 'DISKS must support discard (TRIM/UNMAP)'
#
-# Some tests are not applicable to Linux or need to be updated to operate
-# in the manor required by Linux. Any tests which are skipped for this
+# Some tests are not applicable to a platform or need to be updated to operate
+# in the manor required by the platform. Any tests which are skipped for this
# reason will be suppressed in the final analysis output.
#
@@ -300,7 +307,7 @@ if __name__ == "__main__":
issue_url = 'https://github.com/openzfs/zfs/issues/'
# Include the reason why the result is expected, given the following:
- # 1. Suppress test results which set the "N/A on Linux" reason.
+ # 1. Suppress test results which set the "Not applicable" reason.
# 2. Numerical reasons are assumed to be GitHub issue numbers.
# 3. When an entire test group is skipped only report the setup reason.